package com.usky.fire.controller.web;


import com.usky.common.core.bean.ApiResult;
import com.usky.common.core.bean.CommonPage;
import com.usky.fire.domain.DemPoliceInfo;
import com.usky.fire.service.DemMicroStationService;
import com.usky.fire.service.DemPoliceInfoService;
import com.usky.fire.service.vo.AlertStatisticsVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 警情信息 前端控制器
 * </p>
 *
 * @author JCB
 * @since 2022-10-24
 */
@RestController
@RequestMapping("/demPoliceInfo")
public class DemPoliceInfoController {

    @Autowired
    private DemMicroStationService demMicroStationService;

    @Autowired
    private DemPoliceInfoService demPoliceInfoService;

    /**
     * 综合警情-撒点
     *
     * @param streetTown    街镇
     * @param scattererType 撒点类型
     * @return
     */
    @GetMapping("synthesizePoliceSituationScatterer")
    public ApiResult<List<Object>> synthesizePoliceSituationScatterer(@RequestParam(value = "streetTown", required = false) String streetTown,
                                                                      @RequestParam(value = "scattererType", required = false) String scattererType) {
        return ApiResult.success(demMicroStationService.synthesizePoliceSituationScatterer(streetTown, scattererType));
    }

    /**
     * 综合警情-查询每年12个月警情
     *
     * @return
     */
    @GetMapping("/alertStatisticsByMonth")
    public ApiResult<Map<String, List<AlertStatisticsVO>>> getAlertStatisticsByMonth(@RequestParam String startTime,
                                                                                     @RequestParam String endTime,
                                                                                     @RequestParam(value = "streetTown", required = false) String streetTown) {
        return ApiResult.success(demPoliceInfoService.getAlertStatisticsByMonth(startTime, endTime, streetTown));
    }

    /**
     * 查询不同警情(社会救助，警情，火灾)的占比
     *
     * @param startTime 开始时间
     * @param endTime   结束时间
     * @return
     */
    @GetMapping("/alertStatistics")
    public ApiResult<List<AlertStatisticsVO>> getAlertStatistics(@RequestParam(value = "startTime") String startTime,
                                                                 @RequestParam(value = "endTime") String endTime,
                                                                 @RequestParam(value = "streetTown", required = false) String streetTown) {
        return ApiResult.success(demPoliceInfoService.getAlertStatistics(startTime, endTime, streetTown));
    }

    /**
     * 警情详细信息
     *
     * @param current   页数
     * @param size      条数
     * @param startTime 开始时间
     * @param endTime   结束时间
     * @return
     */
    @GetMapping("/page")
    public ApiResult<CommonPage<DemPoliceInfo>> page(@RequestParam(value = "startTime", required = false) String startTime,
                                                     @RequestParam(value = "endTime", required = false) String endTime,
                                                     @RequestParam(value = "streetTown", required = false) String streetTown,
                                                     @RequestParam(value = "current", required = false, defaultValue = "1") Integer current,
                                                     @RequestParam(value = "size", required = false, defaultValue = "10") Integer size) {
        return ApiResult.success(demPoliceInfoService.page(current, size, startTime, endTime, streetTown));
    }


    /**
     * 综合警情-警情时段分布
     *
     * @param startTime 开始时间
     * @param endTime   结束时间
     * @return
     */
    @GetMapping("/alertStatisticsByHouse")
    public ApiResult<Map<String, List<AlertStatisticsVO>>> getAlertStatisticsByHouse(@RequestParam(value = "startTime") String startTime,
                                                                                     @RequestParam(value = "endTime") String endTime,
                                                                                     @RequestParam(value = "streetTown", required = false) String streetTown) {
        return ApiResult.success(demPoliceInfoService.getAlertStatisticsByHouse(startTime, endTime, streetTown));
    }


    /**
     * 综合警情-警情撒点
     *
     * @param streetTown 街镇
     * @return
     */
    @GetMapping("/warningInstanceScatterer")
    public ApiResult<List<Map<String, Object>>> warningInstanceScatterer(@RequestParam(value = "streetTown", required = false) String streetTown) {
        return ApiResult.success(demPoliceInfoService.warningInstanceScatterer(streetTown));
    }
}

